.. include:: ../warning.rst

The 'download' views
====================

.. automodule:: cubicweb_web.views.idownloadable

Components
----------

.. autoclass:: cubicweb_web.views.idownloadable.DownloadBox

Download views
--------------

.. autoclass:: cubicweb_web.views.idownloadable.DownloadView
.. autoclass:: cubicweb_web.views.idownloadable.DownloadLinkView
.. autoclass:: cubicweb_web.views.idownloadable.IDownloadablePrimaryView
.. autoclass:: cubicweb_web.views.idownloadable.IDownloadableOneLineView

Embedded views
--------------

.. autoclass:: cubicweb_web.views.idownloadable.ImageView
.. autoclass:: cubicweb_web.views.idownloadable.EHTMLView
